diff eval.h @ 11596:e22a96273dc4 libavcodec

Rename AVEvalExpr to AVExpr, as suggested by Michael. The new name is shorter and less confusing.
author stefano
date Sun, 11 Apr 2010 11:47:29 +0000
parents 116f25bad5fb
children fce0ed54244c
line wrap: on
line diff
--- a/eval.h	Sun Apr 11 11:47:24 2010 +0000
+++ b/eval.h	Sun Apr 11 11:47:29 2010 +0000
@@ -28,7 +28,7 @@
 #ifndef AVCODEC_EVAL_H
 #define AVCODEC_EVAL_H
 
-typedef struct ff_expr_s AVEvalExpr;
+typedef struct ff_expr_s AVExpr;
 
 /**
  * Parses and evaluates an expression.
@@ -58,10 +58,10 @@
  * @param func1_name NULL terminated array of zero terminated strings of func1 identifers
  * @param func2_name NULL terminated array of zero terminated strings of func2 identifers
  * @param error pointer to a char* which is set to an error message if something goes wrong
  * @return AVEvalExpr which must be freed with ff_eval_free by the user when it is not needed anymore
  *         NULL if anything went wrong
  */
-AVEvalExpr * ff_parse(const char *s, const char * const *const_name,
+AVExpr * ff_parse(const char *s, const char * const *const_name,
                double (**func1)(void *, double), const char **func1_name,
                double (**func2)(void *, double, double), const char **func2_name,
                const char **error);
@@ -71,8 +71,8 @@
  * @param opaque a pointer which will be passed to all functions from func1 and func2
  * @return the value of the expression
  */
-double ff_parse_eval(AVEvalExpr * e, const double *const_value, void *opaque);
-void ff_eval_free(AVEvalExpr * e);
+double ff_parse_eval(AVExpr * e, const double *const_value, void *opaque);
+void ff_eval_free(AVExpr * e);
 
 /**
  * Parses the string in numstr and returns its value as a double. If
@@ -58,10 +58,10 @@
  * @param func2_name NULL terminated array of zero terminated strings of func2 identifers
  * @param error pointer to a char* which is set to an error message if something goes wrong
- * @return AVEvalExpr which must be freed with ff_eval_free by the user when it is not needed anymore
+ * @return AVExpr which must be freed with ff_eval_free by the user when it is not needed anymore
  *         NULL if anything went wrong
  */